package org.scalatest.inspectors.all

import org.scalatest._
import org.scalatest.matchers.{BePropertyMatcher, BePropertyMatchResult, HavePropertyMatcher, HavePropertyMatchResult}
import collection.GenTraversable
import collection.GenMap
class InspectorShorthandsForAllFailedSpec9 extends Spec with Matchers with SharedHelpers {
  class EmptyBePropertyMatcher extends BePropertyMatcher[String] {
    def apply(left: String) = BePropertyMatchResult(left.isEmpty, "empty")
  }
  class StringLengthMatcher(expectedValue: Int) extends HavePropertyMatcher[String, Int] {
    def apply(value: String) = {
      new HavePropertyMatchResult(value.length == expectedValue, "length", expectedValue, value.length)
    }
  }
  val empty = new EmptyBePropertyMatcher()
  def plength(expectedValue: Int) = new StringLengthMatcher(expectedValue)
  val theInstance = "2"
  def arrayToString(xs: GenTraversable[_]): String = xs.toString
  def checkErrorAndCause(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String, causeErrorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
    e.getCause match {
      case tfe: exceptions.TestFailedException =>
        assert(tfe.failedCodeFileName == Some(fileName), tfe.failedCodeFileName + " did not equal " + Some(fileName))
        assert(tfe.failedCodeLineNumber == Some(assertLineNumber), tfe.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
        assert(tfe.message == Some(causeErrorMessage), tfe.message + " did not equal " + Some(causeErrorMessage))
        assert(tfe.getCause == null, tfe.getCause + " was not null")
      case other => fail("Expected cause to be TestFailedException, but got: " + other)
    }
  }
  def checkError(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
  }
  def equal[T](left: T, right: T): Boolean = left == right
  def javaArrayList[T](valueList: List[T]): java.util.ArrayList[T] = {
    val col = new java.util.ArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashSet[T](valueList: List[T]): java.util.HashSet[T] = {
    val col = new java.util.HashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedList[T](valueList: List[T]): java.util.LinkedList[T] = {
    val col = new java.util.LinkedList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaStack[T](valueList: List[T]): java.util.Stack[T] = {
    val col = new java.util.Stack[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaTreeSet[T](valueList: List[T]): java.util.TreeSet[T] = {
    val col = new java.util.TreeSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaVector[T](valueList: List[T]): java.util.Vector[T] = {
    val col = new java.util.Vector[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayBlockingQueue[T](valueList: List[T], size: Int): java.util.concurrent.ArrayBlockingQueue[T] = {
    val col = new java.util.concurrent.ArrayBlockingQueue[T](size)
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayDeque[T](valueList: List[T]): java.util.ArrayDeque[T] = {
    val col = new java.util.ArrayDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentLinkedQueue[T](valueList: List[T]): java.util.concurrent.ConcurrentLinkedQueue[T] = {
    val col = new java.util.concurrent.ConcurrentLinkedQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentSkipListSet[T](valueList: List[T]): java.util.concurrent.ConcurrentSkipListSet[T] = {
    val col = new java.util.concurrent.ConcurrentSkipListSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArrayList[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArrayList[T] = {
    val col = new java.util.concurrent.CopyOnWriteArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArraySet[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArraySet[T] = {
    val col = new java.util.concurrent.CopyOnWriteArraySet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingDeque[T](valueList: List[T]): java.util.concurrent.LinkedBlockingDeque[T] = {
    val col = new java.util.concurrent.LinkedBlockingDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingQueue[T](valueList: List[T]): java.util.concurrent.LinkedBlockingQueue[T] = {
    val col = new java.util.concurrent.LinkedBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedHashSet[T](valueList: List[T]): java.util.LinkedHashSet[T] = {
    val col = new java.util.LinkedHashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityBlockingQueue[T](valueList: List[T]): java.util.concurrent.PriorityBlockingQueue[T] = {
    val col = new java.util.concurrent.PriorityBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityQueue[T](valueList: List[T]): java.util.PriorityQueue[T] = {
    val col = new java.util.PriorityQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashMap[K, V](valueMap: Map[K, V]): java.util.HashMap[K, V] = {
    val map = new java.util.HashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaTreeMap[K, V](valueMap: Map[K, V]): java.util.TreeMap[K, V] = {
    val map = new java.util.TreeMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaHashtable[K, V](valueMap: Map[K, V]): java.util.Hashtable[K, V] = {
    val map = new java.util.Hashtable[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentHashMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentHashMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentSkipListMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentSkipListMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentSkipListMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaLinkedHashMap[K, V](valueMap: Map[K, V]): java.util.LinkedHashMap[K, V] = {
    val map = new java.util.LinkedHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaWeakHashMap[K, V](valueMap: Map[K, V]): java.util.WeakHashMap[K, V] = {
    val map = new java.util.WeakHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaProperties(valueMap: Map[String, String]): java.util.Properties = {
    val map = new java.util.Properties()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaTreeMap(Map.empty[String, String]), javaTreeMap(Map("b" -> "boom!")), javaTreeMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Array(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Vector(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaHashtable(Map.empty[String, String]), javaHashtable(Map("b" -> "boom!")), javaHashtable(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Array(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Vector(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Set(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `(new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!")))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.Seq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = collection.mutable.IndexedSeq(javaConcurrentHashMap(Map.empty[String, String]), javaConcurrentHashMap(Map("b" -> "boom!")), javaConcurrentHashMap(Map("h" -> "hello!"))).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Set(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = List(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain key' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain key "b"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainKey[String, String](xs, "b") + " did not contain key \"b\"")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain key' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain key ("b")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainKey[String, String](xs, "b")) + ", " + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainKey[String, String](xs, "b") + " contained key \"b\"")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should contain value' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should contain value "boom!"
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapNotContainValue[String, String](xs, "boom!") + " did not contain value \"boom!\"")
  }
  def `Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not contain value' failed` {
    val xs = Seq(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not contain value ("boom!")
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapContainValue[String, String](xs, "boom!")) + ", " + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\" (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstJavaMapContainValue[String, String](xs, "boom!") + " contained value \"boom!\"")
  }
  def `Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should be symbol' failed` {
    val xs = Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapNotIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapNotIsEmpty[String, String](xs, 0) + " was not empty")
  }
  def `Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not be symbol' failed` {
    val xs = Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapIsEmpty[String, String](xs, 0)) + ", " + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapIsEmpty[String, String](xs, 0) + " was empty")
  }
  def `Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have size' failed` {
    val xs = Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have size 0")
  }
  def `Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have size' failed` {
    val xs = Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had size 1")
  }
  def `Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should have length' failed` {
    val xs = Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeNotEqual[String, String](xs, 0)) + ", " + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeNotEqual[String, String](xs, 0) + " did not have length 0")
  }
  def `Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!"))) should throw TestFailedException with correct stack depth and message when 'java map should not have length' failed` {
    val xs = Array(javaConcurrentSkipListMap(Map.empty[String, String]), javaConcurrentSkipListMap(Map("b" -> "boom!")), javaConcurrentSkipListMap(Map("h" -> "hello!")))
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (1)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec9.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstJavaMapSizeEqual[String, String](xs, 1)) + ", " + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1 (InspectorShorthandsForAllFailedSpec9.scala:" + assertLineNumber + ") \n" + 
  "in " + arrayToString(xs), "" + getFirstJavaMapSizeEqual[String, String](xs, 1) + " had length 1")
  }
}
